@@ -2,7 +2,7 @@ use crate::setup::Path;
 use crate::structs;
 use hyper_tls::HttpsConnector;
 use hyper::body;
-use hyper::{Client, Error, Body, Response};
+use hyper::{Client};
 use hyper::client::connect::HttpConnector;
 use http::uri::Uri;
 use serde_json;
